@@ -4,19 +4,25 @@ from tkinter.ttk import *
 from tkinter import *
 from ttkthemes import ThemedStyle
 
-from TMTool.Scripts import template2xlsx
-from TMTool.Scripts import xlsx2template
+from TMTool.Scripts.Template import template2xlsx
+from TMTool.Scripts.Template import xlsx2template
 from TMTool.Scripts import jira_issues
 from TMTool.Scripts import fix_report_hyperlinks
 from TMTool.Scripts import set_metadata_tags
 
+root = Tk()
+
 def open_script1():
     template2xlsx.main()
     print("executed template2xlsx")
+    root.destroy()
+    quit()
 
 def open_script2():
     xlsx2template.main()
     print("executed xlsx2template")
+    root.destroy()
+    return
 
 def open_script3():
     jira_issues.main()
@@ -29,11 +35,11 @@ def open_script4():
 def open_script5(root):
     root.destroy()
     set_metadata_tags.main()
+    # TODO: inspect block
     print("executed set_metadata_tags")
 
 
 def main():
-    root = Tk()
     root.configure(background='#404040')
     root.title("TMTool GUI")
     root.geometry("400x200")
@@ -66,7 +72,7 @@ def main():
 
     button5 = ttk.Button(window,
                     text="Set Model metadata",
-                    command= (lambda: open_script5(root)))
+                    command= open_script5)
 
     # light green
     text1 = ttk.Label(window,
@@ -87,7 +93,7 @@ def main():
     button4.grid(row=2, column=1, sticky=W+E)
     button5.grid(row=1, column=1, sticky=W+E)
     root.mainloop()
-    return
+    quit()
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
